pub struct TestVector {Show 13 fields
pub tx: Vec<u8>,
pub txid: [u8; 32],
pub auth_digest: [u8; 32],
pub amounts: Vec<i64>,
pub script_pubkeys: Vec<Vec<u8>>,
pub transparent_input: Option<u32>,
pub sighash_shielded: [u8; 32],
pub sighash_all: Option<[u8; 32]>,
pub sighash_none: Option<[u8; 32]>,
pub sighash_single: Option<[u8; 32]>,
pub sighash_all_anyone: Option<[u8; 32]>,
pub sighash_none_anyone: Option<[u8; 32]>,
pub sighash_single_anyone: Option<[u8; 32]>,
}Expand description
A ZIP-244 test vector with the transaction input and expected outputs.
Fields
tx: Vec<u8>The serialized transaction.
txid: [u8; 32]The expected transaction ID.
auth_digest: [u8; 32]The expected auth digest.
amounts: Vec<i64>The amounts of the outputs matching each transparent input
script_pubkeys: Vec<Vec<u8>>The script pubkey of the outputs matching each transparent input
transparent_input: Option<u32>Which transparent input the ID refers to, if any.
sighash_shielded: [u8; 32]The signature hash for shielded transactions.
sighash_all: Option<[u8; 32]>The signature hash for the SIGHASH_ALL type.
sighash_none: Option<[u8; 32]>The signature hash for the SIGHASH_NONE type.
sighash_single: Option<[u8; 32]>The signature hash for the SIGHASH_SINGLE type.
sighash_all_anyone: Option<[u8; 32]>The signature hash for the SIGHASH_ALL type with SIGHASH_ANYONECANPAY set.
sighash_none_anyone: Option<[u8; 32]>The signature hash for the SIGHASH_NONE type with SIGHASH_ANYONECANPAY set.
sighash_single_anyone: Option<[u8; 32]>The signature hash for the SIGHASH_SINGLE type with SIGHASH_ANYONECANPAY set.